MORSE_CODE_DICT = {'A': '.-',
                   'B': '-...',
                   'C': '-.-.',
                   'D': '-..',
                   'E': '.',
                   'F': '..-.',
                   'G': '--.',
                   'H': '....',
                   'I': '..',
                   'J': '.---',
                   'K': '-.-',
                   'L': '.-..',
                   'M': '--',
                   'N': '-.',
                   'O': '---',
                   'P': '.--.',
                   'Q': '--.-',
                   'R': '.-.',
                   'S': '...',
                   'T': '-',
                   'U': '..-',
                   'V': '...-',
                   'W': '.--',
                   'X': '-..-',
                   'Y': '-.--',
                   'Z': '--..',
                   '1': '.----',
                   '2': '..---',
                   '3': '...--',
                   '4': '....-',
                   '5': '.....',
                   '6': '-....',
                   '7': '--...',
                   '8': '---..',
                   '9': '----.',
                   '0': '-----',
                   ', ': '--..--',
                   '.': '.-.-.-',
                   '?': '..--..',
                   '/': '-..-.',
                   '-': '-....-',
                   '(': '-.--.',
                   ')': '-.--.-'
}

ANIMALS_FACTS = [
    {"question": "What is the name of the fastest land animal?", "answer": "Cheetah"},
    {"question": "What’s the only mammal that’s able to fly?", "answer": "Bat"},
    {"question": "What’s a group of kittens called?", "answer": "Kindle"},
    {"question": "What are the horns of a rhinoceros made of?", "answer": "Hair"},
    {"question": "What name is given to a female deer?", "answer": "Doe"},
    {"question": "What animal is known by the nickname “sea cow?”", "answer": "Manatees"},
    {"question": "What animal is said to have 9 lives?", "answer": "Cat"},
    {"question": "What is the only mammals that can’t jump?", "answer": "Elephant"},
    {"question": "What animal eats mainly bamboo?", "answer": "Panda"},
    {"question": "Which animal can stand on its tail?", "answer": "Kangaroo"},
    {"question": "Which animal is the tallest in the world?", "answer": "Giraffe"},
    {"question": "What animal is covered in quills?", "answer": "Porcupine"}
]